#
# spec file for package ibus-libpinyin
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2023 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define   with_cloud_input   1

Name:           ibus-libpinyin
Version:        1.16.3
Release:        1.1
Summary:        Intelligent Pinyin engine based on libpinyin for IBus
License:        GPL-3.0-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/libpinyin/ibus-libpinyin
Source0:        https://github.com/libpinyin/ibus-libpinyin/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  gnome-common
BuildRequires:  ibus-devel >= 1.5.11
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  libuuid-devel
BuildRequires:  opencc-devel >= 1.0.0
BuildRequires:  pkgconfig
BuildRequires:  sqlite3
BuildRequires:  sqlite3-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpinyin) >= 2.9.92
BuildRequires:  pkgconfig(lua)
%if %{with_cloud_input}
BuildRequires:  pkgconfig(json-glib-1.0) >= 1.0
BuildRequires:  pkgconfig(libsoup-3.0) >= 3.0
%endif
%if 0%{?sle_version} < 150600 && 0%{?sle_version} >= 150000
BuildRequires:  python310-base
Requires:       python310-base
Requires:       python310-gobject-Gdk
%else
BuildRequires:  python3-base
Requires:       python3-base
Requires:       python3-gobject-Gdk
%endif
Provides:       locale(ibus:zh_CN;zh_SG)
%{ibus_requires}

%description
It includes a Chinese Pinyin input method and a Chinese ZhuYin (Bopomofo) input
method based on libpinyin for IBus.

%prep
%autosetup -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure --disable-static \
           --enable-opencc \
           --disable-boost \
           --libexecdir=%{_ibus_libexecdir} \
           --libdir=%{_libdir} \
%if %{with_cloud_input}
           --enable-cloud-input-mode \
%endif
%if 0%{?sle_version} < 150600 && 0%{?sle_version} >= 150000
           PYTHON=python3.10
%else
           PYTHON=python3
%endif

%make_build

%install
%make_install

%fdupes %{buildroot}
%find_lang %{name}

%suse_update_desktop_file ibus-setup-libpinyin Utility DesktopUtility System
%suse_update_desktop_file ibus-setup-libbopomofo Utility DesktopUtility System

%fdupes %{buildroot}

%files -f %{name}.lang
%defattr(-,root,root)
%license COPYING
%doc AUTHORS README NEWS
%{_ibus_libexecdir}/ibus-engine-libpinyin
%{_ibus_libexecdir}/ibus-setup-libpinyin
%{_datadir}/applications/ibus-setup-libbopomofo.desktop
%{_datadir}/applications/ibus-setup-libpinyin.desktop
%{_datadir}/%{name}/base.lua
%{_datadir}/%{name}/user.lua
%{_datadir}/%{name}/db/english.db
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/db
%dir %{_datadir}/metainfo
%{_datadir}/%{name}/icons
%{_datadir}/%{name}/setup
%{_datadir}/%{name}/network.txt
%{_datadir}/%{name}/default.xml
%{_datadir}/ibus-libpinyin/db/table.db
%{_datadir}/metainfo/libpinyin.appdata.xml
%{_datadir}/ibus
%{_datadir}/glib-2.0/schemas/com.github.libpinyin.ibus-libpinyin.gschema.xml

%changelog
* Fri May 23 2025 Cliff Zhao <qzhao@suse.com>
- Update to version 1.16.3:
  * fix cloud input
* Thu Apr  3 2025 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.16.2
  * Support punctuation candidate
  * Notify user when import file finished
  * Display lua converters in ibus panel
  * Support square bracket page option
  * Fix bugs
- Drop ibus-libpinyin-revert-python-3.2.patch, merged by upstream
* Mon Sep 23 2024 Cliff Zhao <qzhao@suse.com>
- Update ibus-libpinyin.spec:
  Change python depending version, Since tumbleweed and SLE already
  totally switch to python3, no longer coexist with python2.
  (boo#1228652)
* Mon Sep 23 2024 Cliff Zhao <qzhao@suse.com>
- Add ibus-libpinyin-revert-python-3.2.patch:
  Backporting cf67e92a from upstream, Revert python3 version
  checking to 3.2 to enable lower python version building.
  (boo#1228652)
* Thu Sep 12 2024 Cliff Zhao <qzhao@suse.com>
- Update version to 1.15.8:
  GtkDialog "type-hint" changed to dialog;
  Fix lua plugin;
  Update the Copyright year in setup dialog;
  Update opencc-config to use s2tw.json;
* Thu Aug  1 2024 Hillwood Yang <hillwood@opensuse.org>
- Fix boo#1228652
  * Use default python3 version
  * need python311-gobject-Gdk on Leap 15 and python3-gobject-Gdk on Tumbleweed
* Tue Feb 20 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.15.7
  * Fix bugs
* Tue Jan 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Fixes for %%_ibus_libexecdir moving to %%_libexecdir (bsc#1174075)
* Wed Dec 27 2023 Cliff Zhao <qzhao@suse.com>
- Update ibus-libpinyin.spec: Change build requirement and installation
  requirement from python310 to python311 in SLE-15-SP6 and later
  release, since there's no python310 provided yet.
  (bsc#1218160)
* Sun Dec  3 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.15.5
  * Use libsoup3
  * Update network dictionary
  * Fix Caps Lock for English mode
  * Fix bugs
* Fri Jun  9 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.15.3
  * Fix English mode in Full Pinyin
* Mon Mar 20 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.15.2
  * Fix bugs
- Drop fix-sqlite-3_41_0-support.patch, merged
* Sun Feb 26 2023 Hillwood Yang <hillwood@opensuse.org>
- Add fix-sqlite-3_41_0-support.patch, fix build on sqlite 3.41.0
* Tue Feb 21 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.15.1
  * Require libpinyin 2.7.91
  * Improve suggestion candidates
  * Improve English candidates
  * Support longer candidates
  * Support Legacy mode
  * Fix bugs
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 1.13.1:
  * fix setup dialog
* Mon Aug 22 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.13.0
  * Fix bugs
* Thu Apr 14 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.12.91
  * Enhance English input mode
  * Enhance Table input mode
  * Update setup dialog
* Thu Sep 16 2021 Dingzhong Chen <wsxy162@gmail.com>
- Update version to 1.12.1
  * support compatibility display style
  * remember cloud input
  * bug fixes
* Sat Jan  9 2021 Dingzhong Chen <wsxy162@gmail.com>
- Update version to 1.12.0
  * bug fixes
* Fri Oct 23 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.11.94
  * support cloud input
  * bug fixes
* Thu Aug 27 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.11.93
  * switch to use GPLv3+ license
  * support network dictionary
  * bug fixes
* Fri Mar 27 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.11.92
  * Support compact display style
  * Fix bugs
* Fri Dec  6 2019 Cliff Zhao <qzhao@suse.com>
- Update ibus-libpinyin.spec: Remove dependence to pyxdg, because
  it has been removed since 1.6.92 (bnc#1158513).
* Fri May 31 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.11.1
  * Use gettext
  * Add emoji-candidate option (boo#1112998)
  * Fix SuggestionEditor
* Thu Feb 14 2019 hillwood@opensuse.org
- Update version to 1.11.0
  * Fix keypad decimal
  * Fix emoji candidates
  * Support configurable opencc config
- Drop ibus-libpinyin-fix-build-fault.patch, merged by upstream.
* Fri Nov 30 2018 qzhao@suse.com
- Update ibus-libpinyin.spec: To adapt to tumbleweed's update to
  python3.
* Mon Nov 19 2018 qzhao@suse.com
- Modify ibus-libpinyin.spec: Add python3 compile condition to
  avoid ibus-libpinyin-setup crash in Tumbleweed's mixed
  environment(boo#1116485).
* Sat Nov 17 2018 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.10.92
  * Fixes Enter handling
* Tue Nov 13 2018 qzhao@suse.com
- Add ibus-libpinyin-fix-build-fault.patch: fix build error for
  edition 1.10 in openSUSE-Leap-15(boo#1115778).
* Fri Oct 12 2018 hillwood@opensuse.org
- Update version to 1.10.91
  * Support ime.register_trigger in lua extension
  * Support predicted candidates
  * Support emoji input
* Mon May 21 2018 hillwood@opensuse.org
- Update version to 1.10.0
  * bug fixes
* Wed Mar 14 2018 hillwood@opensuse.org
- Drop ibus-libpinyin-build_lua_5.2.patch, merged by upstream.
* Mon Mar  5 2018 hillwood@opensuse.org
- Update version to 1.9.3
  * Translate input method name in ibus menu
  * Remove phrases.txt
* Thu Sep 28 2017 hillwood@opensuse.org
- Update to 1.9.2
  * fixes pinyin and bopomofo config
* Tue Aug 29 2017 hillwood@opensuse.org
- Update to 1.9.1
  * add sort candidate option to setup dialog
* Tue Aug 22 2017 hillwood@opensuse.org
- Update to 1.9.0
  * change dconf key name to lower case
  * use libpinyin 1.9.91
  * fixes config in setup dialog
* Fri Sep  9 2016 hillwood@opensuse.org
- Update to 1.8.0
  * use libpinyin 1.6.0
* Thu Aug 11 2016 hillwood@opensuse.org
- Fix lua build on openSUSE leap.
  * add ibus-libpinyin-build_lua_5.2.patch
* Wed Aug 10 2016 hillwood@opensuse.org
- Update to 1.7.92
  * use ibus 1.5.11
  * use libpinyin 1.5.92
  * work around getLookupCursor
* Fri Dec 25 2015 i@marguerite.su
- update version 1.7.4
  * use pinyin_in_chewing_keyboard method
  * fixes m_bopomofo_keyboard_mapping option
- changes in version 1.7.3
  * use libpinyin 1.2.91
  * add Catalan
  * fix for lua 5.2 API change (luaL_register is deprecated)
  * update clearPinyinUserData method
  * update m_dictionaries
  * use pinyin_load_addon_phrase_library function
  * update setup dialog
* Wed Sep 30 2015 hillwood@opensuse.org
- Update tp 1.7.2
  * Fix for Lua 5.2 API change (luaL_register is deprecated)
  * update po files
  * update clearPinyinUserData method
  * update m_dictionaries
  * use pinyin_load_addon_phrase_library function
  * update setup dialog
  * fixes a typo
  * add libpinyin.appdata.xml
- Fix boo#947676
* Wed Apr  8 2015 hillwood@linuxfans.org
- Update to 1.7.1
  * select the first item in shortcut editor
  * fixes shortcut keys in setup dialog
  * fixes default values
* Fri Feb 20 2015 hillwood@linuxfans.org
- Fix Requires error.
* Sun Feb 15 2015 hillwood@linuxfans.org
- Update to 1.6.99.20150203
  * update class LibPinyinConfig to support export user phrases
  * update setup dialog UI
  * write exportPinyinDictionary method
  * use opencc 1.0
* Fri Feb 28 2014 hillwood@linuxfans.org
- update to 1.6.92
  * minor bug fixes
* Wed Oct 30 2013 hillwood@linuxfans.org
- add python-xdg as Requires
* Fri Jul 12 2013 hillwood@linuxfans.org
- enable lua support
- bring it as default in DVD, add Provides tag
* Mon Jul  8 2013 hillwood@linuxfans.org
- update to 1.6.91
  * update libpinyin requires
* Sun Apr 28 2013 hillwood@linuxfans.org
- update to 1.5.92
  * fixes setup dialog
  * change config key name
  * add using namespace pinyin
  * remove special phrases
  * re-factor ExtEditor
  * update base.lua
  * fixes download url in bus-libpinyin.spec.in
  * fixes getLookupCursor
  * update main2.py
  * update po files
  * polish UI
  * and more ..
* Sun Jan 27 2013 hillwood@linuxfans.org
- update to 1.4.93.
  * detect libpinyin datadir
  * fixes bopomofo icon
  * fixes ';' in double pinyin
  * add symbol to libpinyin.xml.in.in
  * add libpinyin depends
  * fixes automake
* Mon Jul 16 2012 hillwood@linuxfans.org
- update to 1.4.91，the first release of 1.5.x series.
- Add new options to setup dialog
* Mon Jul 16 2012 hillwood@linuxfans.org
- update to 1.4.1
  * fixes fillLookupTableByPage
* Thu Jul  5 2012 hillwood@linuxfans.org
- add a requires package, opencc is needed by ibus-libpinyin
* Sun Jul  1 2012 hillwood@linuxfans.org
- add a .desktop file
* Sun Jul  1 2012 hillwood@linuxfans.org
- enable opencc support
* Fri Jun 22 2012 hillwood@linuxfans.org
- Initial package from ibus-libpinyin git, version 1.4.0.20120612
